pub struct InMemoryCoordinationStore { /* private fields */ }Expand description
Deterministic coordination store for embedded control planes and tests.
Implementations
Sourceimpl InMemoryCoordinationStore
impl InMemoryCoordinationStore
Sourcepub fn with_schema_version(schema_version: u64) -> Self
pub fn with_schema_version(schema_version: u64) -> Self
Creates a store at an explicit schema version for migration tests.
Sourcepub fn set_healthy(&self, healthy: bool)
pub fn set_healthy(&self, healthy: bool)
Changes the deterministic health result.